Block

Enum Block 

#[repr(C)]
pub enum Block {
Show 14 variants Air = 0, Cobblestone = 1, Granite = 2, Andesite = 3, Diorite = 4, Lapis = 5, Iron = 6, Gold = 7, Diamond = 8, Redstone = 9, Emerald = 10, Dirt = 11, OakLog = 12, OakLeaves = 13,
}
An enum representing a Minecraft block. This contains all the block types currently supported by wasmcraft2, which is a very limited subset of Minecraft’s block selection. There is currently no way to place any other blocks through wasmcraft2.

Variants



Air = 0



Cobblestone = 1



Granite = 2



Andesite = 3



Diorite = 4



Lapis = 5



Iron = 6



Gold = 7



Diamond = 8



Redstone = 9



Emerald = 10



Dirt = 11



OakLog = 12



OakLeaves = 13