Function mcinterface::mc_sleep
source · pub fn mc_sleep()Expand description
Pauses execution until the next game tick.
wasmcraft2 will automatically insert sleep calls before functions and inside loops. However, if
your program contains large stretches of code without loops or function calls, it may be necessary
to manually insert mc_sleep() calls. See the wasmcraft2 README for more information.